==> tolstoy_agents-0.1.44.tar.gz: tolstoy_agents-0.1.44/tolstoy_agents/tools/support_human_tool.py <==
from pydantic import BaseModel, Field
from langchain.tools import StructuredTool
from typing import List, Optional

class SupportToolInput(BaseModel):
    internal_question: str = Field(
        ..., description="Question to ask the internal support team. This will be sent to our internal slack channel. Always start your message with <!channel> to notify the team."
    )
    user_message: str = Field(
        ..., description="Message to display to the user while waiting for internal support. This will be sent to the user as a reply to their message. Don't reveal you're consulting others, just say you're looking into it or checking internally."
    )

def ask_support(internal_question: str, user_message: str) -> str:
    return f"INTERNAL: {internal_question}\nUSER: {user_message}"

def support_human_tool_factory() -> StructuredTool:
    return StructuredTool.from_function(
        func=ask_support,
        name="ask_internal_support",
        description=(
            "Use this tool when you need to check something internally or require "
            "assistance from the internal team. Provide both the internal question "
            "and a message for the user that doesn't reveal you're consulting others."
            "You can use this tool to ask the internal team to help you with a task, to answer a question that you don't know because the context you have is not enough, or to do something that you don't have ability, tell internal team about the user's request."
        ),
        args_schema=SupportToolInput,
        return_direct=False
    )

==> tolstoy_agents-0.1.45.tar.gz: tolstoy_agents-0.1.45/tolstoy_agents/tools/support_human_tool.py <==
from pydantic import BaseModel, Field
from langchain.tools import StructuredTool
from typing import List, Optional

class SupportToolInput(BaseModel):
    internal_question: str = Field(
        ..., description="Question to ask the internal support team. This will be sent to our internal slack channel that Niezl and Mikaela manage. Always start your message with <!Niezl><!Mikaela> to notify the both of them, It should always be both of them"
    )
    user_message: str = Field(
        ..., description="Message to display to the user while waiting for internal support. This will be sent to the user as a reply to their message. Don't reveal you're consulting others, just say you're looking into it or checking internally."
    )

def ask_support(internal_question: str, user_message: str) -> str:
    return f"INTERNAL: {internal_question}\nUSER: {user_message}"

def support_human_tool_factory() -> StructuredTool:
    return StructuredTool.from_function(
        func=ask_support,
        name="ask_internal_support",
        description=(
            "Use this tool when you need to check something internally or require "
            "assistance from the internal team. Provide both the internal question "
            "and a message for the user that doesn't reveal you're consulting others."
            "You can use this tool to ask the internal team (Niezl and Mikaela) to answer a question that you don't know because the context you have is not enough, or to do something that you don't have ability, tell internal team about the user's request."
        ),
        args_schema=SupportToolInput,
        return_direct=False
    )
